@@ -1,5 +1,6 @@
 import numpy as np
 import pyneb as pn
+
 if pn.config.INSTALLED['plt']:
     import matplotlib.pyplot as plt
 if pn.config.INSTALLED['scipy']:
@@ -45,7 +46,7 @@ class RedCorr(object):
         
         Parameters:
             - E_BV [float]: differential extinction between bands B and V
-            - R_V = AV/E_BV
+            - R_V = AV/E_BV. Default value is 3.1
             - law [str]: one of the defined laws (available with RedCorr.getLaws()) 
             - cHbeta: logarithmic extinction at Hbeta (prevalence on E_BV)
             - UserFunction X(wave, param): A user-defined function that accept 2 parameters: wavelength(s) in Angstrom 
@@ -98,7 +99,7 @@ class RedCorr(object):
             - ebv    E(B-V)
             
         """
-        Xbeta = self.X(4861.)
+        Xbeta = self.X(pn.CST.HBETA)
         return 0.4 * ebv * Xbeta
         #return np.asarray((-0.61 + (0.61 ** 2 + 4 * 0.024 * ebv) ** 0.5) / (2 * 0.024))
     
@@ -114,7 +115,7 @@ class RedCorr(object):
             - cHbeta
             
         """
-        Xbeta = self.X(4861.)
+        Xbeta = self.X(pn.CST.HBETA)
         if Xbeta != 0.:
             return cHbeta * 2.5 / Xbeta
         else:
@@ -140,7 +141,7 @@ class RedCorr(object):
                 doc = self._laws_dict[law].__doc__
             except:
                 doc = ''
-            print "'{0}': {1}".format(law, doc)
+            print("'{0}': {1}".format(law, doc))
                          
     def _get_e_bv(self):
         return self.__E_BV
@@ -244,7 +245,7 @@ class RedCorr(object):
             - wave      wavelength (Angstrom)
         
         """
-        return self.getCorr(wave, np.ones_like(wave) * 4861.)
+        return self.getCorr(wave, np.ones_like(wave) * pn.CST.HBETA)
     
     
     def getErrCorr(self, wave, err_E_BV, rel_wave=None):
@@ -274,7 +275,7 @@ class RedCorr(object):
             - err_E_BV     error on E(B-V)
 
         """
-        return self.getErrCorr(self, wave, err_E_BV, rel_wave=4861.)
+        return self.getErrCorr(self, wave, err_E_BV, rel_wave=pn.CST.HBETA)
 
     
     def setCorr(self, obs_over_theo, wave1, wave2):
@@ -345,7 +346,7 @@ class RedCorr(object):
         Cardelli, Clayton & Mathis 1989, ApJ 345, 245
         http://adsabs.harvard.edu/abs/1989ApJ...345..245C
 
-        Comments: Depends on R_V
+        Comments: Depends on R_V, default value being 3.1
 
         Scope: Applicable to both dense and diffuse ISM
         Range: UV through IR
@@ -400,7 +401,7 @@ class RedCorr(object):
         Same as CCM89 for x<3.3 and x>8
         Revised values for 3.3<x<8
         Based on observation of Orion stars
-        Depends on R_V
+        Depends on R_V, default value being 3.1
 
         Range: UV through IR
         
