@@ -19,8 +19,8 @@ def Chianti_getA(ion_chianti, NLevels=None):
         As_O3 = Chianti_getA('o_3')
     """
     wgfa = _chianti_tools.wgfaRead(ion_chianti)
-    NLevels = np.max(wgfa['lvl2'])
-    As = np.zeros((NLevels, NLevels))
+    NLevels_ori = np.max(wgfa['lvl2'])
+    As = np.zeros((NLevels_ori, NLevels_ori))
     for i, j, a in zip(wgfa['lvl2'], wgfa['lvl1'], wgfa['avalue']):
         As[i-1, j-1] = a
     if NLevels is not None:
@@ -162,6 +162,8 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
             if len(isplups) == 0:
                 ups = np.zeros(ntemp)
             else:
+                if len(isplups) > 1 or np.ndim(isplups)==1:
+                    isplups = isplups[0]
                 ttype=Splups["ttype"][isplups]
                 cups=Splups["cups"][isplups]
                 if pn.config.Chianti_version_main == '8':
@@ -269,10 +271,10 @@ class _AtomChianti(object):
         if self.NLevels is None:
             self.NLevels = len(self.Chianti_E)
         self.NIST = getLevelsNIST(self.atom, self.NLevels)
-        self.NLevels = np.min((len(self.NIST), self.NLevels))
         need_NIST = True
         
         if self.NIST is not None:
+            self.NLevels = np.min((len(self.NIST), self.NLevels))    
             energy = self.NIST['energy'] / 1e8
             stat_weight = 1 + 2 * self.NIST['J']
             self.comments['VACUUM'] = '1'
@@ -457,7 +459,9 @@ class _CollChianti(object):
         self._CollArray = Chianti_getOmega(self.ion_chianti, tem=self._TemArray, 
                                    Splups=self.Splups, NLevels=self.NLevels)
         
+        self.NLevels = np.min((self._CollArray.shape[0]-1, self._CollArray.shape[1]-1, self.NLevels))
         self.Chianti2NIST = get_levs_order(self.atom, NLevels=self.NLevels)
+        
         if self.Chianti2NIST is not None:
             _CollArray_tmp = self._CollArray.copy()
             for i_chianti in self.Chianti2NIST:
